@@ -10,6 +10,9 @@ AWS_ENV_DOCS = "https://github.com/Quansight/qhub/blob/master/docs/docs/aws/inst
 GCP_ENV_DOCS = "https://github.com/Quansight/qhub/blob/master/docs/docs/gcp/installation.md#environment-variables"
 AZURE_ENV_DOCS = "Coming Soon"
 
+# Regex for suitable project names
+namestr_regex = r"^[A-Za-z][A-Za-z\-_]*[A-Za-z]$"
+
 
 @contextlib.contextmanager
 def timer(logger, prefix):
